v2.4.0
======

Features
--------

- Presented hg_repo and git_repo as fixtures. (#36)


v2.3.1
======

No significant changes.


v2.3.0
======

Features
--------

- Added Git.age method.


v2.2.0
======

Features
--------

- Remove check on minimum git version.


v2.1.0
======

Features
--------

- Added .get_timestamp method for retrieving the timestamp of a given revision.


v2.0.0
======

Features
--------

- Implement subrepos for Git repos.


Deprecations and Removals
-------------------------

- Removed legacy names.


v1.3.0
======

Features
--------

- Remove mask for environment when invoking hg as the underlying issue has been corrected. (#7)


v1.2.0
======

Features
--------

- Require Python 3.8 or later.


v1.1.0
======

Added ``repo()`` function.

Implemented ``Git.get_ancestral_tags()``.

v1.0.0
======

Initial release, based on ``hgtools`` 10.
